Summary:          A shared storage lock manager
Name:             sanlock
Version:          3.8.5
Release:          3%{?dist}
License:          GPLv2 and GPLv2+ and LGPLv2+
URL:              https://pagure.io/sanlock/
Source0:          https://releases.pagure.org/sanlock/%{name}-%{version}.tar.gz

BuildRequires:    gcc make python3
BuildRequires:    libaio-devel libblkid-devel libuuid-devel python3-devel
BuildRequires:    systemd-units python3-setuptools
Requires:         %{name}-lib = %{version}-%{release}
Requires(pre):    /usr/sbin/groupadd
Requires(pre):    /usr/sbin/useradd
Requires(post):   systemd-units
Requires(post):   systemd-sysv
Requires(preun):  systemd-units
Requires(postun): systemd-units

%description
sanlock is a lock manager built on shared storage. Hosts with access
to the storage can perform locking. An application running on the 
hosts is given a small amount of space on the shared block device or
file, and uses sanlock for its own application-specific synchroniza‐
tion. Internally, the sanlock daemon manages locks using two disk-
based lease algorithms: delta leases and paxos leases.

%package        lib
Summary:        A shared storage lock manager library

%description    lib
This package provides the runtime libraries for sanlock, a shared storage
lock manager.Hosts connected to a common SAN can use this to synchronize
their access to the shared disks.

%package        -n python3-sanlock
Summary:        Python bindings for the sanlock library
Requires:       %{name}-lib = %{version}-%{release}
Provides:       python-sanlock = %{version}-%{release}
Provides:       python%{python3_version}-sanlock = %{version}-%{release}

%description    -n python3-sanlock
This package provides a module that permits applications written
in the Python programming language to use the interface supplied
by the sanlock library.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}-lib = %{version}-%{release}

%description    devel
This package provides libraries and header files for developing
applications that use %{name}.

%prep
%autosetup -n %{name}-%{version} -p1

%build
make -C wdmd
make -C src
make -C python PY_VERSION=3

%install
rm -rf %{buildroot}
make -C src                       \
        install LIBDIR=%{_libdir} \
        DESTDIR=%{buildroot}
make -C wdmd                      \
        install LIBDIR=%{_libdir} \
        DESTDIR=%{buildroot}
make -C python                    \
        install LIBDIR=%{_libdir} \
        DESTDIR=%{buildroot}      \
        PY_VERSION=3


install -D -m 0644 init.d/sanlock.service.native %{buildroot}/%{_unitdir}/sanlock.service
install -D -m 0755 init.d/wdmd %{buildroot}/usr/lib/systemd/systemd-wdmd
install -D -m 0644 init.d/wdmd.service.native %{buildroot}/%{_unitdir}/wdmd.service

install -D -m 0644 src/logrotate.sanlock %{buildroot}/etc/logrotate.d/sanlock
install -D -m 0644 src/sanlock.conf %{buildroot}/etc/sanlock/sanlock.conf
install -D -m 0644 init.d/wdmd.sysconfig %{buildroot}/etc/sysconfig/wdmd

install -Dd -m 0755 %{buildroot}/etc/wdmd.d
install -Dd -m 0775 %{buildroot}/%{_localstatedir}/run/sanlock

%pre
getent group sanlock > /dev/null || /usr/sbin/groupadd \
    -g 179 sanlock
getent passwd sanlock > /dev/null || /usr/sbin/useradd \
    -u 179 -c "sanlock" -s /sbin/nologin -r \
    -g 179 -d /var/run/sanlock sanlock
/usr/sbin/usermod -a -G disk sanlock

%post
%systemd_post wdmd.service sanlock.service

%preun
%systemd_preun wdmd.service sanlock.service

%postun
%systemd_postun wdmd.service sanlock.service

%files
%doc init.d/sanlock
%doc init.d/sanlock.service
%doc init.d/wdmd.service
%config(noreplace) %{_sysconfdir}/logrotate.d/sanlock
%config(noreplace) %{_sysconfdir}/sanlock/sanlock.conf
%config(noreplace) %{_sysconfdir}/sysconfig/wdmd
/usr/lib/systemd/systemd-wdmd
%{_unitdir}/sanlock.service
%{_unitdir}/wdmd.service
%{_sbindir}/sanlock
%{_sbindir}/wdmd
%dir %{_sysconfdir}/wdmd.d
%dir %{_sysconfdir}/sanlock
%dir %attr(-,sanlock,sanlock) %{_localstatedir}/run/sanlock
%{_mandir}/man8/wdmd*
%{_mandir}/man8/sanlock*

%files          lib
%{_libdir}/libsanlock.so.*
%{_libdir}/libsanlock_client.so.*
%{_libdir}/libwdmd.so.*

%files          -n python3-sanlock
%{python3_sitearch}/sanlock_python-*.egg-info
%{python3_sitearch}/sanlock*.so

%files          devel
%{_libdir}/libwdmd.so
%{_libdir}/libsanlock.so
%{_libdir}/libsanlock_client.so
%{_libdir}/pkgconfig/libsanlock.pc
%{_libdir}/pkgconfig/libsanlock_client.pc
%{_includedir}/wdmd.h
%{_includedir}/sanlock.h
%{_includedir}/sanlock_rv.h
%{_includedir}/sanlock_admin.h
%{_includedir}/sanlock_resource.h
%{_includedir}/sanlock_direct.h

%changelog
* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.8.5-3
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.8.5-2
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Aug 23 2023 Shuo Wang <abushwang@tencent.com> - 3.8.5-1
- update to 3.8.5

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.8.4-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.8.4-2
- Rebuilt for OpenCloudOS Stream 23

* Thu Sep 8 2022 Shuo Wang <abushwang@tencent.com> - 3.8.4-1
- initial build
